##  Introduction
Once the integration is set up successfully, SaaS applications are automatically discovered and listed in the SaaS discovery inbox. In the inbox, you can review the SaaS applications, link them to existing fact sheets, or create and link to new fact sheets.
